@@ -18,18 +18,26 @@ impl MessageBox {
     ///
     /// # Examples
     ///
-    /// ```
+    ///There are several types of DIALOGSTYLE for the second argument
+    /// - DIALOGSTYLE_NONE
+    /// - DIALOGSTYLE_INFO
+    /// - DIALOGSTYLE_QUESTION
+    /// - DIALOGSTYLE_EXCLAMATION
+    /// - DIALOGSTYLE_ERROR
+    ///```
     /// use windows_sys::Win32::UI::WindowsAndMessaging::*;
     /// use nxui::messagebox;
     /// use nxui::NativesAndMessaging::*;
     ///
+    /// //
+    ///
     /// fn main() {
     ///     let msg_box = messagebox::MessageBox { title: "This is a test".to_string().parse().unwrap(), message: "Hello World".to_string().parse().unwrap() };
-    ///     msg_box.show(BUTTONSTYLE_OK,WINDOWSTYLE_MODAL);
+    ///     msg_box.show(BUTTONSTYLE_OK,DIALOGSTYLE_INFO,DIALOGHINT_MODAL);
     /// }
     /// ```
     #[cfg(windows)]
-    pub fn show(&self,button_type: MESSAGEBOX_STYLE,window_style: u64) {
+    pub fn show(&self,button_type: MESSAGEBOX_STYLE,dialog_style: MESSAGEBOX_STYLE,window_style: u64) {
         use windows_sys::{
             Win32::Foundation::*, Win32::System::Threading::*, Win32::UI::WindowsAndMessaging::*,
         };
@@ -38,21 +46,20 @@ impl MessageBox {
             SetEvent(event);
             WaitForSingleObject(event, 0);
             CloseHandle(event);
-
-            MessageBoxA(window_style.try_into().unwrap(), self.message.as_ptr(), self.title.as_ptr(), button_type);
+            MessageBoxA(window_style.try_into().unwrap(), self.message.as_ptr(), self.title.as_ptr(), dialog_style|button_type);
         }
     }
     #[cfg(linux)]
-    pub fn show(&self,button_type: ButtonsType,window_style: DialogFlags) {
+    pub fn show(&self,button_type: ButtonsType,dialog_style: MessageType,window_style: DialogFlags) {
         use gtk::prelude::*;
         let dialog = gtk::MessageDialog::new(
             Some(&window_),
             window_style,
-            gtk::MessageType::Info,
-            button_type
+            dialog_style,
+            button_type,
             &message
         );
         dialog.run();
         dialog.destroy();
     }
-}
\ No newline at end of file
+}
